@@ -4,7 +4,7 @@
 from pyiArduinoI2Cph import *
 
 #   Объявляем объект sensor для работы с функциями и методами библиотеки pyiArduinoI2Cph, указывая адрес модуля на шине I2C.
-pyiArduinoI2Cph sensor(0x09)
+sensor = pyiArduinoI2Cph(0x09)
 
 #   Устанавливаем водородный показатель 1 жидкости для калибровки модуля кнопкой от 0 до 14,000 pH.
 sensor.setKnownPH (1, 4.00)
