@@ -127,6 +127,18 @@ bool	iarduino_I2C_pH::setCalibration	(uint8_t num, float pH){																//
 			}																													//
 }																																//
 																																//
+//		Получение текущей стадии калибровки модуля:																				//	Возвращаемое значение:	стадия калибровки (0-нет, 1, 2)
+uint8_t	iarduino_I2C_pH::getCalibration	(void){																					//	Параметр:				отсутствует.
+			if(valAddr){																										//	Если модуль был инициализирован, то ...
+			//	Читаем данные из модуля:																						//
+				_readBytes(REG_PH_CALIBRATION, 1);																				//	Читаем 1 байт из регистра «REG_TDS_CALIBRATION» в массив «data».
+			//	Возвращаем результат:																							//
+				if(data[0]&PH_FLG_STATUS_1){return 1;}																			//	Выполняется 1 стадия калибровки.
+				if(data[0]&PH_FLG_STATUS_2){return 2;}																			//	Выполняется 2 стадия калибровки.
+			}																													//
+			return 0;																											//	Калибровка не выполняется.
+}																																//
+																																//
 //		Получение водородного показателя жидкости требуемого для калибровки модуля с кнопки:									//	Возвращаемое значение:	водородный показатель калибровочной жидкости.
 float	iarduino_I2C_pH::getKnownPH		(uint8_t num){																			//	Параметр:				стадия калибровки (1 или 2).
 			if(valAddr){																										//	Если модуль был инициализирован, то ...
@@ -136,7 +148,7 @@ float	iarduino_I2C_pH::getKnownPH		(uint8_t num){																			//	Пара
 				_readBytes(num==1? REG_PH_KNOWN_PH_1:REG_PH_KNOWN_PH_2, 2);														//	Читаем 2 байта из регистров «REG_PH_KNOWN_PH_1» или «REG_PH_KNOWN_PH_2» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)( ((uint16_t)data[1]<<8) | data[0] )/1000.0f;														//	Возвращаем результат, преобразовав значение из тысячных долей pH.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -165,7 +177,7 @@ float	iarduino_I2C_pH::getKy			(void){																					//	Параметр:
 				_readBytes(REG_PH_Ky, 2);																						//	Читаем 2 байта из регистра «REG_PH_Ky» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)( ((uint16_t)data[1]<<8) | data[0] )/1000.0f;														//	Возвращаем результат, преобразовав значение из тысячных долей.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -193,7 +205,7 @@ float	iarduino_I2C_pH::getVstp		(void){																					//	Параметр:
 				_readBytes(REG_PH_Ustp, 2);																						//	Читаем 2 байта из регистра «REG_PH_Ustp» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)( ((uint16_t)data[1]<<8) | data[0] )/100.0f;														//	Возвращаем результат, преобразовав значение из сотых долей мВ.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -221,7 +233,7 @@ float	iarduino_I2C_pH::getVin			(void){																					//
 				_readBytes(REG_PH_Uin, 2);																						//	Читаем 2 байта из регистра «REG_PH_Uin» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)( ((uint16_t)data[1]<<8) | data[0] )/10000.0f;													//	Возвращаем результат, преобразовав значение из десятитысячных долей В.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -232,7 +244,7 @@ float	iarduino_I2C_pH::getVout		(void){																					//	Параметр:
 				_readBytes(REG_PH_Uout, 2);																						//	Читаем 2 байта из регистра «REG_PH_Uout» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)( ((uint16_t)data[1]<<8) | data[0] )/10000.0f;													//	Возвращаем результат, преобразовав значение из десятитысячных долей В.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -243,7 +255,7 @@ float	iarduino_I2C_pH::getVn			(void){																					//	Параметр:
 				_readBytes(REG_PH_Un, 2);																						//	Читаем 2 байта из регистра «REG_PH_Un» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)( ((uint16_t)data[1]<<8) | data[0] )/10000.0f;													//	Возвращаем результат, преобразовав значение из десятитысячных долей В.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -254,7 +266,7 @@ float	iarduino_I2C_pH::getPHn			(void){																					//	Параметр:
 				_readBytes(REG_PH_pHn, 2);																						//	Читаем 2 байта из регистра «REG_PH_pHn» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)( ((uint16_t)data[1]<<8) | data[0] )/1000.0f;														//	Возвращаем результат, преобразовав значение из тысячных долей.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -282,7 +294,7 @@ float	iarduino_I2C_pH::getPH			(void){																					//	Параметр:
 				_readBytes(REG_PH_pH, 2);																						//	Читаем 2 байта из регистра «REG_PH_pH» в массив «data».
 			//	Возвращаем результат:																							//
 				return (float)( ((uint16_t)data[1]<<8) | data[0] )/1000.0f;														//	Возвращаем результат, преобразовав значение из тысячных долей.
-			}																													//	
+			}																													//
 			return 0;																											//	Возвращаем ошибку.
 }																																//
 																																//
@@ -307,4 +319,4 @@ bool	iarduino_I2C_pH::_writeBytes	(uint8_t reg, uint8_t sum, uint8_t num){
 			delay(10);																											//	Ждём применения модулем записанных данных.
 			return result;																										//	Возвращаем результат записи (true/false).
 }																																//
-																																//
\ No newline at end of file
+																																//
