@@ -1,5 +1,5 @@
 //  Библиотека для работы с Trema модулем pH-метр, I2C-flash для Arduino: https://iarduino.ru/shop/Sensory-Datchiki/datchik-kislotnosti-zhidkosti-ph-metr-flash-i2c.html
-//  Версия: 1.0.0
+//  Версия: 1.1.1
 //  Последнюю версию библиотеки Вы можете скачать по ссылке: https://iarduino.ru/file/559.html
 //  Подробное описание функций бибилиотеки доступно по ссылке: https://wiki.iarduino.ru/page/ph-i2c/
 //  Библиотека является собственностью интернет магазина iarduino.ru и может свободно использоваться и распространяться!
@@ -46,6 +46,8 @@
 #define         REG_PH_Un               0x1B                                                                    //  Адрес регистра содержащего нейтральное напряжение на выходе усилителя в десятитысячных долях В (два байта). Напряжение каким оно должно быть при отсутствии смещения напряжения датчиком.
 #define         REG_PH_pH               0x1D                                                                    //  Адрес регистра содержащего кислотность жидкости в тысячных долях pH (два байта).
 //              Позиция битов и флагов:                                                                         //
+#define         PH_FLG_STATUS_2         0x80                                                                    //  Флаг  регистра REG_PH_CALIBRATION информирует о выполнении 2 стадии калибровки.
+#define         PH_FLG_STATUS_1         0x40                                                                    //  Флаг  регистра REG_PH_CALIBRATION информирует о выполнении 1 стадии калибровки.
 #define         PH_BIT_CALC_2           0x02                                                                    //  Бит   регистра REG_PH_CALIBRATION указывает модулю выполнить 2 стадию калибровки модуля.
 #define         PH_BIT_CALC_1           0x01                                                                    //  Бит   регистра REG_PH_CALIBRATION указывает модулю выполнить 1 стадию калибровки модуля.
                                                                                                                 //
@@ -66,6 +68,7 @@ class iarduino_I2C_pH{
         bool                getPullI2C          (void               );                                          //  Объявляем  функцию возвращающую флаг наличия подтяжки шины I2C          (Параметр:  отсутствует).
         bool                setPullI2C          (bool=true          );                                          //  Объявляем  функцию установки    подтяжки шины I2C                       (Параметр:  флаг подтяжки).
         bool                setCalibration      (uint8_t, float     );                                          //  Объявляем  функцию запуска      калибровки модуля                       (Параметры: стадия 1 или 2, pH от 0 до 14,000).
+        uint8_t             getCalibration      (void               );                                          //  Объявляем  функцию получения    текущей стадии калибровки модуля        (Параметр:  отсутствует).
         float               getKnownPH          (uint8_t            );                                          //  Объявляем  функцию получения    pH для калибровки модуля с кнопки       (Параметр:  стадия 1 или 2).
         bool                setKnownPH          (uint8_t, float     );                                          //  Объявляем  функцию установки    pH для калибровки модуля с кнопки       (Параметр:  стадия 1 или 2, pH от 0 до 14,000).
         float               getKy               (void               );                                          //  Объявляем  функцию получения    коэффициента усиления усилителя         (Параметр:  отсутствует).
